# gb-prob-dist package

This package can be used for applications related to Gaussian and Binomial probability distributions.
It is developed as a course project for the Udacity Machine Learning Engineer Nano-Degree.

# Files

./distributions/Generaldistribution.py
./distributions/Gaussiandistribution.py
./distributions/Binomialdistribution.py

# Installation

pip install gb-prob-dist
